SourceDiagnostic

Struct SourceDiagnostic 

pub struct SourceDiagnostic {
    pub level: DiagnosticLevel,
    pub file_path: FilePath,
    pub message: SharedString,
    pub excerpts: Vec<SourceExcerpt>,
}
Structured source diagnostic with excerpts and inline annotations.

Fields

level: DiagnosticLevel

Severity level of the diagnostic.

file_path: FilePath

Primary file associated with the diagnostic.

message: SharedString

User-facing summary message.

excerpts: Vec<SourceExcerpt>

Relevant excerpts that help explain the diagnostic.

Implementations

Source

impl SourceDiagnostic

pub fn new( level: DiagnosticLevel, file_path: impl Into<FilePath>, message: impl Into<SharedString>, ) -> Self

Creates a source diagnostic from its level, file path, and message.

pub fn with_excerpt(self, excerpt: SourceExcerpt) -> Self

Returns a copy of this diagnostic with one appended excerpt.